==> apache-inlong-1.11.0-src.tar.gz: apache-inlong-1.11.0/inlong-sort/sort-common/src/test/java/org/apache/inlong/sort/protocol/node/load/OracleLoadNodeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.protocol.node.load;

import org.apache.inlong.sort.SerializeBaseTest;
import org.apache.inlong.sort.formats.common.StringFormatInfo;
import org.apache.inlong.sort.protocol.FieldInfo;
import org.apache.inlong.sort.protocol.transformation.FieldRelation;

import java.util.Collections;

/**
 * Test for {@link OracleLoadNode}
 */
public class OracleLoadNodeTest extends SerializeBaseTest<OracleLoadNode> {

    @Override
    public OracleLoadNode getTestObject() {
        return new OracleLoadNode("1", "mysql_output",
                Collections.singletonList(new FieldInfo("NAME", new StringFormatInfo())),
                Collections.singletonList(new FieldRelation(new FieldInfo("name",
                        new StringFormatInfo()), new FieldInfo("NAME", new StringFormatInfo()))),
                null, null, 1, null,
                "jdbc:oracle:thin:@localhost:1521:xe",
                "inlong",
                "inlong",
                "user",
                "name");
    }
}

==> apache-inlong-1.12.0-src.tar.gz: apache-inlong-1.12.0/inlong-sort/sort-common/src/test/java/org/apache/inlong/sort/protocol/node/load/OracleLoadNodeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.protocol.node.load;

import org.apache.inlong.common.pojo.sort.dataflow.field.format.StringFormatInfo;
import org.apache.inlong.sort.SerializeBaseTest;
import org.apache.inlong.sort.protocol.FieldInfo;
import org.apache.inlong.sort.protocol.transformation.FieldRelation;

import java.util.Collections;

/**
 * Test for {@link OracleLoadNode}
 */
public class OracleLoadNodeTest extends SerializeBaseTest<OracleLoadNode> {

    @Override
    public OracleLoadNode getTestObject() {
        return new OracleLoadNode("1", "mysql_output",
                Collections.singletonList(new FieldInfo("NAME", new StringFormatInfo())),
                Collections.singletonList(new FieldRelation(new FieldInfo("name",
                        new StringFormatInfo()), new FieldInfo("NAME", new StringFormatInfo()))),
                null, null, 1, null,
                "jdbc:oracle:thin:@localhost:1521:xe",
                "inlong",
                "inlong",
                "user",
                "name");
    }
}
